.. index::
   single: ptweens; --help

.. _ptweens_script:

.. autoprogram:: pyramid.scripts.ptweens:PTweensCommand.parser
    :prog: ptweens

.. seealso:: :ref:`displaying_tweens` and :ref:`running-pscripts`.
